==> AdvancedContent-0.8.tgz: AdvancedContent/lang/ext/nl_NL.php <==
<?php
$lang['AdvancedContent'] = 'Advanced Content ';
$lang['advancedcontent_tabname'] = 'Geavanceerde Opties';
$lang['installed'] = 'Module AdvancedContent %s is ge&iuml;nstalleerd';
$lang['uninstalled'] = 'Module AdvancedContent %s is gede&iuml;nstalleerd';
$lang['upgraded'] = 'Module AdvancedContent is bijgewerkt naar %s';
$lang['postinstall'] = 'Module AdvancedContent %s is ge&iuml;nstalleerd';
$lang['postuninstall'] = 'Module AdvancedContent %s is gede&iuml;nstalleerd';
$lang['confirmuninstall'] = 'Weet u zeker dat u de module AdvancedContent wilt de&iuml;nstalleren?';
$lang['notice_duplicatecontent'] = '<em><strong>Let op:</strong> Dit blok komt meerdere keren voor in het sjabloon. Alleen het eerste blok wordt hier getoond.</em>';
$lang['error_basicattrib'] = '<em><strong>Notice:</strong> Cannot use basic content property name &#039;%s&#039; as value of param &#039;block&#039;. <br />This block is disabled. Check your page template and chose a different value of param &#039;block&#039;.</em>';
$lang['error_expiredate'] = 'Einddatum moet na de startdatum vallen';
$lang['youareintext'] = 'Huidige directory';
$lang['dimensions'] = 'Afbeelding Afmetingen';
$lang['size'] = 'Bestandsgrootte';
$lang['inherit_from_parent'] = 'Neem over van de ouder';
$lang['none'] = 'geen';
$lang['invalid'] = 'fout';
$lang['invalid_blocktype'] = '<em><strong>Notice:</strong> Invalid value &#039;%s&#039; of param block_type in block &#039;%s&#039;.<br />Check your page template.</em>';
$lang['error_insufficient_blockparams'] = '<em><strong>Error:</strong> Insufficient params. <br />Missing param &#039;%s&#039; for block &#039;%s&#039;. Check your page template.</em>';
$lang['yes'] = 'Ja';
$lang['no'] = 'Nee';
$lang['frontendaccess'] = 'Frontend Toegang';
$lang['redirectpage'] = 'Verwijzen naar pagina indien geen toegang';
$lang['showloginform'] = 'Toon login formulier';
$lang['registeredusers'] = 'Alleen geregistreerde gebruikers';
$lang['block'] = 'Block ';
$lang['useexpiredate'] = 'Gebruik verloopdatum';
$lang['startdate'] = 'Start Datum';
$lang['enddate'] = 'Eind Datum';
$lang['blockcontent'] = 'Block Inhoud';
$lang['setpageinactive'] = 'Pagina Inactief';
$lang['deletepage'] = 'Verwijder Pagina';
$lang['uninstallaction'] = 'De&iuml;nstalleer bewerking';
$lang['setcontent1'] = 'Stel alle pagina&#039;s in met het type Content';
$lang['setcontent2'] = 'Stel alle pagina&#039;s in met het type Content en verwijder alle extra content blocks';
$lang['prefsupdated'] = 'Voorkeuren bijgewerkt';
$lang['success'] = 'Ok&eacute;';
$lang['error'] = 'Fout';
$lang['deletepages'] = 'Verwijder alle pagina&#039;s met het type AdvancedContent';
$lang['importpages'] = 'Stel alle pagina&#039;s in met het type %s naar het type %s.';
$lang['confirmimport'] = 'Weet u zeker dat u het contenttype van alle pagina&#039;s wil wijzigen?';
$lang['toggle_message'] = 'Verberg dit bericht';
$lang['contentsettings'] = 'Standaard AdvancedContent Instellingen';
$lang['redirectparams'] = 'URL params to append when redirecting (param1=value1 param2=value2 ...)';
$lang['evaluatesmarty'] = 'Use smarty to create the params';
$lang['error_loading_module'] = '<em><strong>Error:</strong> Could not load module &#039;%s&#039;. (Defined for block &#039;%s&#039; in your page template.)</em>';
$lang['error_contentblock_support'] = '<em><strong>Error:</strong> Module &#039;%s&#039; does not support contentblocks. (Defined for block &#039;%s&#039; in your page template.)</em>';
$lang['success_importpages'] = 'Alle pagina&#039;s van het type %s zijn succesvol gewijzigd naar %s';
$lang['show_advancedcontent_options'] = 'Geef AdvancedContent opties tabblad weer';
$lang['display_settings'] = '%s weergave instellingen';
$lang['save_collapse_status'] = 'Sla de inklapstatus op van %s';
$lang['content_blocks'] = 'content blokken';
$lang['block_message'] = 'content blok bericht';
$lang['block_groups'] = 'blok groepen';
$lang['collapse_default'] = 'Klap %s standaard in';
$lang['per_page'] = 'per pagina';
$lang['per_template'] = 'per sjabloon';
$lang['both1'] = 'sjabloon OF pagina ';
$lang['both2'] = 'sjabloon EN pagina';
$lang['content'] = 'Inhoud';
$lang['content2'] = 'Advanced Content ';
$lang['prefs'] = 'Instellingen';
$lang['multi_input'] = 'Multi input';
$lang['multi_input_tpl'] = 'Multi inputtemplates';
$lang['add_multi_input'] = 'Voeg nieuwe multi input toe';
$lang['add_multi_input_tpl'] = 'Voeg nieuwe multi inputtemplate toe';
$lang['input_id'] = 'Invoer ID';
$lang['input_fields'] = 'Invoer velden';
$lang['tpl_name'] = 'Sjabloon naam';
$lang['error_template'] = 'De template vereist dit veld en het mag niet leeggelaten worden';
$lang['error_input_fields'] = 'Invoervelden is een vereist veld en mag niet leeggelaten worden.';
$lang['error_input_id'] = 'Geen invoer id gegeven of invoer id bestaat al.';
$lang['error_input_id_exists'] = 'Invoer ID is al in gebruik. Kies een andere (moet uniek zijn).';
$lang['multi_input_added'] = 'Multi Input toegevoegd.';
$lang['multi_input_deleted'] = 'Multi Input verwijderd.';
$lang['multi_input_updated'] = 'Multi Input bijgewerkt.';
$lang['multi_input_tpl_added'] = 'Multi Input template toegevoegd.';
$lang['multi_input_tpl_updated'] = 'Multi Input template bijgewerkt.';
$lang['multi_input_tpl_deleted'] = 'Multi Input template verwijderd.';
$lang['delete_selected'] = 'Verwijder geselecteerde items';
$lang['confirm_delete'] = 'Weet u zeker dat u dit wilt verwijderen?';
$lang['confirm_delete_selected'] = 'Weet u zeker dat u deze wilt verwijderen?';
$lang['hide_content'] = 'Geen (verberg de inhoud)';
$lang['hide_menu_item'] = 'Verbergen van menu';
$lang['loggedout'] = 'indien niet aangemeld';
$lang['loggedin'] = 'indien aangemeld';
$lang['aftercurrdate'] = 'na de huidige datum';
$lang['afterstartdate'] = 'na de startdatum';
$lang['minutes'] = 'minuten';
$lang['hours'] = 'uren';
$lang['days'] = 'dagen';
$lang['weeks'] = 'weken';
$lang['months'] = 'maanden';
$lang['years'] = 'jaren';
$lang['help_tpl_vars'] = '<p><strong>Template vars:</strong></p>
<p><pre><code>{$inputs}</code></pre> is an array that contains all defined input elements of that multi input block.<br />
Each input element is an array that contains all its params. <br />
See module help for more info.<br />
Additional param is &quot;input&quot; that will print out the input element.<br />
To access the params use the dot syntax.<br />
Example:</p>
<pre><code>{foreach from=$inputs item=elm}
	{$elm.label}:&nbsp;{$elm.input}<br />
{/foreach}</code></pre>';
$lang['utma'] = '156861353.1852221271.1287479092.1304422808.1304523790.142';
$lang['utmz'] = '156861353.1304523790.142.88.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/|utmcmd=referral';
$lang['qca'] = 'P0-161031897-1287479092171';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>

==> AdvancedContent-0.9.2.tgz: AdvancedContent/lang/ext/nl_NL.php <==
<?php
$lang['AdvancedContent'] = 'Advanced Content ';
$lang['admindescription'] = 'Advanced content type met aangepaste velden voor het toevoegen/bewerken van het pagina panel en enkele extra functies.';
$lang['advancedcontent_tabname'] = 'Geavanceerde Opties';
$lang['installed'] = 'Module AdvancedContent %s is ge&iuml;nstalleerd';
$lang['uninstalled'] = 'Module AdvancedContent %s is gede&iuml;nstalleerd';
$lang['upgraded'] = 'Module AdvancedContent is bijgewerkt naar %s';
$lang['postinstall'] = 'Module AdvancedContent %s is ge&iuml;nstalleerd';
$lang['postuninstall'] = 'Module AdvancedContent %s is gede&iuml;nstalleerd';
$lang['confirmuninstall'] = 'Weet u zeker dat u de module AdvancedContent wilt de&iuml;nstalleren?';
$lang['warninguninstall'] = 'WAARSCHUWING! U heeft geen de&iuml;nstallatie actie gebruikt in de modulevoorkeuren! Controleer voor de zekerheid dat er geen pagina&#039;s meer staan ingesteld op het type Advanced Content voordat u deze module verwijderd! U kunt anders uw CMS installatie beschadigen! ';
$lang['warninguninstall1'] = 'WAARSCHUWING! Dit zal alle pagina&#039;s verwijderen met het type Advanced Content! ';
$lang['warninguninstall2'] = 'OPMERKING: Dit zal alle pagina&#039;s van het AdvancedContent-type terugplaatsen naar het standaard contenttype.';
$lang['warninguninstall3'] = 'WAARSCHUWING! Dit zal alle pagina&#039;s van het AdvancedContent-type terugplaatsten naar het standaard contenttype, daarnaast zal het alle extra inhoudsblokken verwijderen (behalve het standaard inhoudsblok).';
$lang['notice_duplicatecontent'] = '<em><strong>Let op:</strong> Dit blok komt meerdere keren voor in het sjabloon. Alleen het eerste blok wordt hier getoond.</em>';
$lang['error_basicattrib'] = '<em><strong>Notice:</strong> Cannot use basic content property name &#039;%s&#039; as value of param &#039;block&#039;. <br />This block is disabled. Check your page template and chose a different value of param &#039;block&#039;.</em>';
$lang['error_expiredate'] = 'Einddatum moet na de startdatum vallen';
$lang['youareintext'] = 'Huidige directory';
$lang['dimensions'] = 'Afbeelding Afmetingen';
$lang['size'] = 'Bestandsgrootte';
$lang['inherit_from_parent'] = 'Neem over van de ouder';
$lang['none'] = 'geen';
$lang['invalid'] = 'fout';
$lang['invalid_block'] = '<em><strong>Opmerking:</strong> Ongeldig blok &#039;%s&#039;.<br />Controleer uw paginasjabloon.</em>';
$lang['error_insufficient_blockparams'] = '<em><strong>Fout:</strong> Ongeldige parameters. <br />Missende parameter &#039;%s&#039; voor het blok &#039;%s&#039;. Controleer uw paginasjabloon.</em>';
$lang['yes'] = 'Ja';
$lang['no'] = 'Nee';
$lang['frontendaccess'] = 'Frontend Toegang';
$lang['redirectpage'] = 'Verwijzen naar pagina indien geen toegang';
$lang['showloginform'] = 'Toon login formulier';
$lang['registeredusers'] = 'Alleen geregistreerde gebruikers';
$lang['block'] = 'Block ';
$lang['useexpiredate'] = 'Gebruik verloopdatum';
$lang['startdate'] = 'Start Datum';
$lang['enddate'] = 'Eind Datum';
$lang['blockcontent'] = 'Block Inhoud';
$lang['setpageinactive'] = 'Pagina Inactief';
$lang['deletepage'] = 'Verwijder Pagina';
$lang['uninstallaction'] = 'De&iuml;nstalleer bewerking';
$lang['setcontent1'] = 'Stel alle pagina&#039;s in met het type Content';
$lang['setcontent2'] = 'Stel alle pagina&#039;s in met het type Content en verwijder alle extra content blocks';
$lang['prefsupdated'] = 'Voorkeuren bijgewerkt';
$lang['success'] = 'Ok&eacute;';
$lang['error'] = 'Fout';
$lang['deletepages'] = 'Verwijder alle pagina&#039;s met het type AdvancedContent';
$lang['importpages'] = 'Stel alle pagina&#039;s in met het type %s naar het type %s.';
$lang['confirmimport'] = 'Weet u zeker dat u het contenttype van alle pagina&#039;s wil wijzigen?';
$lang['toggle_message'] = 'Verberg dit bericht';
$lang['contentsettings'] = 'Standaard AdvancedContent Instellingen';
$lang['redirectparams'] = 'URL params to append when redirecting (param1=value1 param2=value2 ...)';
$lang['evaluatesmarty'] = 'Use smarty to create the params';
$lang['error_loading_module'] = '<em><strong>Error:</strong> Could not load module &#039;%s&#039;. (Defined for block &#039;%s&#039; in your page template.)</em>';
$lang['error_contentblock_support'] = '<em><strong>Error:</strong> Module &#039;%s&#039; does not support contentblocks. (Defined for block &#039;%s&#039; in your page template.)</em>';
$lang['success_importpages'] = 'Alle pagina&#039;s van het type %s zijn succesvol gewijzigd naar %s';
$lang['show_advancedcontent_options'] = 'Geef AdvancedContent opties tabblad weer';
$lang['display_settings'] = '%s weergave instellingen';
$lang['save_collapse_status'] = 'Sla de inklapstatus op van %s';
$lang['content_blocks'] = 'content blokken';
$lang['block_message'] = 'content blok bericht';
$lang['block_groups'] = 'blok groepen';
$lang['collapse_default'] = 'Klap %s standaard in';
$lang['per_page'] = 'per pagina';
$lang['per_template'] = 'per sjabloon';
$lang['both1'] = 'sjabloon OF pagina ';
$lang['both2'] = 'sjabloon EN pagina';
$lang['content'] = 'Inhoud';
$lang['content2'] = 'Advanced Content ';
$lang['prefs'] = 'Instellingen';
$lang['multi_input'] = 'Multi input';
$lang['multi_input_tpl'] = 'Multi inputtemplates';
$lang['add_multi_input'] = 'Voeg nieuwe multi input toe';
$lang['add_multi_input_tpl'] = 'Voeg nieuwe multi inputtemplate toe';
$lang['input_id'] = 'Invoer ID';
$lang['input_fields'] = 'Invoer velden';
$lang['tpl_name'] = 'Sjabloon naam';
$lang['error_template'] = 'De template vereist dit veld en het mag niet leeggelaten worden';
$lang['error_input_fields'] = 'Invoervelden is een vereist veld en mag niet leeggelaten worden.';
$lang['error_input_id'] = 'Geen invoer id gegeven of invoer id bestaat al.';
$lang['error_input_id_exists'] = 'Invoer ID is al in gebruik. Kies een andere (moet uniek zijn).';
$lang['multi_input_added'] = 'Multi Input toegevoegd.';
$lang['multi_input_deleted'] = 'Multi Input verwijderd.';
$lang['multi_input_updated'] = 'Multi Input bijgewerkt.';
$lang['multi_input_tpl_added'] = 'Multi Input template toegevoegd.';
$lang['multi_input_tpl_updated'] = 'Multi Input template bijgewerkt.';
$lang['multi_input_tpl_deleted'] = 'Multi Input template verwijderd.';
$lang['delete_selected'] = 'Verwijder geselecteerde items';
$lang['confirm_delete'] = 'Weet u zeker dat u dit wilt verwijderen?';
$lang['confirm_delete_selected'] = 'Weet u zeker dat u deze wilt verwijderen?';
$lang['hide_content'] = 'Geen (verberg de inhoud)';
$lang['hide_menu_item'] = 'Verbergen van menu';
$lang['loggedout'] = 'indien niet aangemeld';
$lang['loggedin'] = 'indien aangemeld';
$lang['aftercurrdate'] = 'na de huidige datum';
$lang['afterstartdate'] = 'na de startdatum';
$lang['minutes'] = 'minuten';
$lang['hours'] = 'uren';
$lang['days'] = 'dagen';
$lang['weeks'] = 'weken';
$lang['months'] = 'maanden';
$lang['years'] = 'jaren';
$lang['switch_params'] = 'Zet alle &#039;%s&#039; naar &#039;%s&#039;.';
$lang['feu_params'] = 'Parameters voor de FrontEndUsers module';
$lang['custom_params'] = 'Aangepaste URL-parameters om toe te voegen bij het doorverwijzen';
$lang['confirm_switchparams'] = 'Weet u zeker dat u de inhoudseigenschap \&#039;%s\&#039; van alle pagina&#039;s wilt wijzigen in \&#039;%s\&#039;?';
$lang['success_switchparams'] = 'Alle eigenschappen zijn gewijzigd';
$lang['custom_blocktypes'] = 'Geavanceerde bloktypes';
$lang['plugins'] = 'Plug-ins';
$lang['help_tpl_vars'] = '<p><strong>Template vars:</strong></p>
<p><pre><code>{$inputs}</code></pre> is an array that contains all defined input elements of that multi input block.<br />
Each input element is an array that contains all its params. <br />
See module help for more info.<br />
Additional param is &quot;input&quot; that will print out the input element.<br />
To access the params use the dot syntax.<br />
Example:</p>
<pre><code>{foreach from=$inputs item=elm}
	{$elm.label}:&nbsp;{$elm.input}<br />
{/foreach}</code></pre>';
$lang['utma'] = '156861353.839426107.1319910072.1319910072.1319910072.1';
$lang['utmz'] = '156861353.1319910072.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/viewtopic.php|utmcmd=referral';
$lang['qca'] = 'P0-856617467-1310370352588';
$lang['utmb'] = '156861353';
$lang['utmc'] = '156861353';
?>
